# RED Connector Semcon

RED Connector Semcon is part of the Curious Containers project.

This connector is designed to read data from a [semantic container](https://www.ownyourdata.eu/en/semcon/).

For more information please refer to the Curious Containers [documentation](https://www.curious-containers.cc/).

## Limitations / Future Work
- Selections within the content of a data entry are partially supported in json format. For any other format this is currently not possible.

## Acknowledgements

The Curious Containers software is developed at [CBMI](https://cbmi.htw-berlin.de/) (HTW Berlin - University of Applied Sciences). The work is supported by the German Federal Ministry of Economic Affairs and Energy (ZIM project BeCRF, grant number KF3470401BZ4), the German Federal Ministry of Education and Research (project deep.TEACHING, grant number 01IS17056 and project deep.HEALTH, grant number 13FH770IX6) and HTW Berlin Booster.
